// CaclulatedColumn.cs  Use a relationship with a calculated column

using System;
using System.Data;
using System.Data.SqlClient;

public class CalculatedColumn
{
    public static void Main() 
    {
        string connectionString = "Data Source=localhost;" +
                   "Initial Catalog=Northwind;Integrated Security=SSPI";
        string SQL = "SELECT * FROM Categories";

        // Create ADO.NET objects.
        SqlConnection con = new SqlConnection(connectionString);
        SqlCommand cmd = new SqlCommand(SQL, con);
        SqlDataAdapter adapter = new SqlDataAdapter(cmd);
        DataSet ds = new DataSet();

        try
        {
            con.Open();
            adapter.Fill(ds, "Categories");
    
            cmd.CommandText = "SELECT * FROM Products";
            adapter.Fill(ds, "Products");
        }
        catch (Exception err)
        {
            Console.WriteLine(err.ToString());
        }
        finally
        {
            con.Close();
        }

        // Create the relationships between the tables.
        DataColumn parentCol = 
                   ds.Tables["Categories"].Columns["CategoryID"];
        DataColumn childCol = ds.Tables["Products"].Columns["CategoryID"];
        DataRelation relation = new DataRelation("Cat_Prod", parentCol,
                                                  childCol);
        ds.Relations.Add(relation);

        // Create a calculated column showing average product price.
        ds.Tables["Categories"].Columns.Add("AveragePrice", typeof(Decimal), "AVG(Child(Cat_Prod).UnitPrice)");

        // Create a calculated column showing total price for all products in a category.
        ds.Tables["Categories"].Columns.Add("TotalPrice", typeof(Decimal), "SUM(Child(Cat_Prod).UnitPrice)");

        // Display table information.
        foreach (DataRow row in ds.Tables["Categories"].Rows)
        {
            Console.WriteLine(row["CategoryName"]);
            Console.WriteLine("\tAverage price in this category: " + row["AveragePrice"]);
            Console.WriteLine("\tPrice to purchase one of everything: " + row["TotalPrice"]);
            Console.WriteLine();
        }
    }
}
