// ----- EXAMPLE 15.5 -------------------------------------

private SqlDataAdapter daConflict;
private DataSet dsConflict;

// ...

// connection and select command strings
String connString = "Data Source=(local);Integrated security=SSPI;" +
    "Initial Catalog=Northwind;";
SqlConnection conn = new SqlConnection(connString);
SqlCommand cmd = new SqlCommand("SELECT * FROM Orders ", conn);

daConflict = new SqlDataAdapter(cmd);

// create the DataSet to store concurrency exceptions and retrieve the
// schema from the data source
dsConflict = new DataSet();
daConflict.FillSchema(dsConflict, SchemaType.Source);

// create command objects using SQL statements
SqlCommand selectCmd = new SqlCommand("SELECT OrderID, CustomerID, " +
    "EmployeeID, OrderDate, RequiredDate, ShippedDate, ShipVia, " +
    "Freight, ShipName, ShipAddress, ShipCity, ShipRegion, " +
    "ShipPostalCode, ShipCountry, rowversion FROM Orders", conn);
SqlCommand updateCommand = new SqlCommand("UPDATE Orders SET " +
    "CustomerID=@CustomerID, EmployeeID=@EmployeeID, " +
    "OrderDate=@OrderDate, RequiredDate=@RequiredDate, " +
    "ShippedDate=@ShippedDate, ShipVia=@ShipVia, Freight=@Freight, " +
    "ShipName=@ShipName, ShipAddress=@ShipAddress, ShipCity=@ShipCity, " +
    "ShipRegion=@ShipRegion, ShipPostalCode=@ShipPostalCode, " +
    "ShipCountry=@ShipCountry " +
    "WHERE OrderID=@OrderID AND rowversion=@rowversion;" +
    "SELECT rowversion WHERE OrderID=@OrderID", conn);

// ... code for delete and insert commands

// set up the parameters
SqlParameterCollection cparams;

// update command parameters
cparams = updateCommand.Parameters;
cparams.Add("@OrderID", SqlDbType.Int, 0, "OrderID");
cparams.Add("@CustomerID", SqlDbType.NChar, 5, "CustomerID");
cparams.Add("@EmployeeID", SqlDbType.Int, 0, "EmployeeID");
cparams.Add("@OrderDate", SqlDbType.DateTime, 0, "OrderDate");
cparams.Add("@RequiredDate", SqlDbType.DateTime, 0, "RequiredDate");
cparams.Add("@ShippedDate", SqlDbType.DateTime, 0, "ShippedDate");
cparams.Add("@ShipVia", SqlDbType.Int, 0, "ShipVia");
cparams.Add("@Freight", SqlDbType.Money, 0, "Freight");
cparams.Add("@ShipName", SqlDbType.NVarChar, 40, "ShipName");
cparams.Add("@ShipAddress", SqlDbType.NVarChar, 60, "ShipAddress");
cparams.Add("@ShipCity", SqlDbType.NVarChar, 15, "ShipCity");
cparams.Add("@ShipRegion", SqlDbType.NVarChar, 15, "ShipRegion");
cparams.Add("@ShipPostalCode", SqlDbType.NVarChar, 10, "ShipPostalCode");
cparams.Add("@ShipCountry", SqlDbType.NVarChar, 15, "ShipCountry");
cparams.Add("@rowversion", SqlDbType.Timestamp, 0, "rowversion");
cparams["@rowversion"].SourceVersion=DataRowVersion.Original;

// ... create parameters for delete and insert commands

// create the data adapter
SqlDataAdapter da = new SqlDataAdapter(selectCmd.CommandText, conn);

// set the ContinueUpdateOnError property so that all records are
// processed regardless of exceptions
da.ContinueUpdateOnError = true;

// add the event handler so that the concurrency exceptions can be added
// to the DataSet containing the conflicts
da.RowUpdated += new SqlRowUpdatedEventHandler(da_RowUpdated);

// set the update commands for the data adapter
da.DeleteCommand = deleteCommand;
da.InsertCommand = insertCommand;
da.UpdateCommand = updateCommand;

// create a new DataSet to receive the data and load the data
DataSet ds = new DataSet();

// load all of the data for the Orders table into the DataSet
da.Fill(ds, "Orders");

// ... code to modify the DataSet

// update the data in the Orders table in the DataSet to the data source
da.Update(ds, "Orders");

private void da_RowUpdated(object sender, SqlRowUpdatedEventArgs e)
{
    if (e.Status == UpdateStatus.ErrorsOccurred &&
        e.Errors.GetType() == typeof(DBConcurrencyException))
    {
        // retrieve the data for the row with concurrency
        // exception and store it to the DataSet with an error message
        daConflict.SelectCommand.Parameters["@ID"].Value
            = (String) e.Row["ID"];
        if(daConflict.Fill(dsConflict, "Orders") == 1)
            e.Row.RowError = "Row has been changed in the database";
        else
            e.Row.RowError = "Row has been deleted from database";

        e.Status = UpdateStatus.Continue;
    }
}